# powfacpy
This package is a wrapper around the Python API of PowerFactory&copy; (power system simulation software by DIgSILENT) with improved syntax and functionality compared to the native API. Please have a look at the [docs](https://fraunhiee-unikassel-powsysstability.github.io/powfacpy/html/index.html) for further information. 

This package is under active development and mainly maintained by Fraunhofer IEE. You are welcome to contribute or feel free to get in touch (contact: simon.eberlein@iee.fraunhofer.de). 
